const path = require('path')
const noParse = require('./index').noParse

// plugin stubs
const webpack = {
  HotModuleReplacementPlugin: () => 'HotModuleReplacementPlugin',
  NoErrorsPlugin: () => 'NoErrorsPlugin'
}

const config = {
  devtool: 'cheap-module-eval-source-map',
  entry: [
    'webpack-hot-middleware/client',
    './src/index'
  ],
  output: {
    path: path.join(__dirname, 'dist'),
    filename: 'bundle.js',
    publicPath: '/dist/'
  },
  plugins: [
    webpack.HotModuleReplacementPlugin(),
    webpack.NoErrorsPlugin()
  ],
  module: {
    loader: [{
      test: /\.js$/,
      loaders: ['babel'],
      include: path.join(__dirname, 'src')
    }]
  }
}

module.exports = noParse(true)(config)

/* Exports:

  {
    devtool: 'cheap-module-eval-source-map',
    entry: [
      'webpack-hot-middleware/client',
      './src/index'
    ],
    output: {
      path: '<path-to-project>/dist',
      filename: 'bundle.js',
      publicPath: '/dist/'
    },
    plugins: [
      'HotModuleReplacementPlugin',
      'NoErrorsPlugin'
    ],
    module: {
      loaders: [{
        test: /\.js$/,
        loader: ['babel'],
        include: '<path-to-project>/src'
      }, {
        test: /(react-dom|react-router)\.js$/,
        loader: 'imports?React=react'
      }],
      noParse: [
        '/node_modules/react/dist/react.js',
        '/node_modules/react-dom/dist/react-dom.js',
        '/node_modules/react-router/umd/ReactRouter.js'
      ]
    }
  }

*/
